###################################################
### chunk number 1: rebmix-code
###################################################
#line 315 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"
######################################################
## R sources for reproducing the results in         ##
##   Marko Nagode:                                  ##
##   rebmix: An R Package for Normal, Lognormal and ##
##   Weibull Finite Mixture Models                  ##
######################################################

options(prompt = "R> ", continue = "+  ", width = 70,
  useFancyQuotes = FALSE, digits = 3)


###################################################
### chunk number 2: rebmix-code
###################################################
#line 325 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

###################
## Preliminaries ##
###################

## load package and set prompt before starting new page to TRUE.

library("rebmix")
devAskNewPage(ask = TRUE)


###################################################
### chunk number 3: rebmix-code
###################################################
#line 340 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

####################
## Galaxy dataset ##
####################

## Load galaxy dataset.

data("galaxy")

## Write dataset into the tab delimited ASCII file.

write.table(galaxy, file = "galaxy.txt", sep = "\t",
  eol = "\n", row.names = FALSE, col.names = FALSE)


###################################################
### chunk number 4: rebmix-code
###################################################
#line 356 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Initialize REBMIX object.

REBMIX <- array(list(NULL), c(3, 3, 3))

## Initialize Table 1.

Table <- NULL


###################################################
### chunk number 5: rebmix-code
###################################################
#line 367 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Estimate number of components, component weights and component parameters.

Preprocessing <- c("histogram", "Parzen window", "k-nearest neighbour")
InformationCriterion <- c("AIC", "BIC", "CLC")
pdf <- c("normal", "lognormal", "Weibull")
K <- list(7:20, 7:20, 2:10)


###################################################
### chunk number 6: rebmix-code
###################################################
#line 377 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

for (i in 1:3) {
  for (j in 1:3) {
    for (k in 1:3) {
      REBMIX[[i, j, k]] <- REBMIX(Dataset = "galaxy.txt",
        Preprocessing = Preprocessing[k],
        D = 0.0025,
        cmax = 12,
        InformationCriterion = InformationCriterion[j],
        pdf = pdf[i],
        K = K[[k]])

      ## Fill in Table 1.

      if (is.null(Table))
        Table <- REBMIX[[i, j, k]]$summary
      else
        Table <- merge(Table, REBMIX[[i, j, k]]$summary, all = TRUE, sort = FALSE)
    }
  }
}


###################################################
### chunk number 7: rebmix-code
###################################################
#line 402 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Visualize Table 1.

Table


###################################################
### chunk number 8: galaxy-fig
###################################################
#line 410 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Visualize Figure 1.

plot(REBMIX[[2, 1, 2]], npts = 1000)


###################################################
### chunk number 9: rebmix-code
###################################################
#line 483 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

##################
## Iris dataset ##
##################

data("iris")

## Split the iris dataset into three subsets for the three Species
## and remove the Species column from the datasets.

iriscolnames <- !(colnames(iris) %in% "Species")

iris1 <- iris[iris$Species == "setosa", iriscolnames]
iris2 <- iris[iris$Species == "versicolor", iriscolnames]
iris3 <- iris[iris$Species == "virginica", iriscolnames]

iris <- iris[ , iriscolnames]

## Write the datasets without the Species information into the tab
## delimited ASCII files.

write.table(iris, file = "iris.txt", sep = "\t",
  eol = "\n", row.names = FALSE, col.names = FALSE)
write.table(iris1, file = "iris1.txt", sep = "\t",
  eol = "\n", row.names = FALSE, col.names = FALSE)
write.table(iris2, file = "iris2.txt", sep = "\t",
  eol = "\n", row.names = FALSE, col.names = FALSE)
write.table(iris3, file = "iris3.txt", sep = "\t",
  eol = "\n", row.names = FALSE, col.names = FALSE)


###################################################
### chunk number 10: rebmix-code
###################################################
#line 515 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Initialize REBMIX object.

REBMIX <- array(list(NULL), c(6, 3))

## Initialize Table 2.

Table <- NULL


###################################################
### chunk number 11: rebmix-code
###################################################
#line 526 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Estimate number of components, component weights and component parameters.

Preprocessing <- c("histogram", "Parzen window", "k-nearest neighbour")
InformationCriterion <- c("AIC", "AWE", "BIC", "CLC", "ICL", "ICL-BIC")
K <- list(6:25, 6:25, 3:13)


###################################################
### chunk number 12: rebmix-code
###################################################
#line 535 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

for (i in 1:6) {
  for (j in 1:3) {
    REBMIX[[i, j]] <- REBMIX(Dataset = c("iris.txt", "iris1.txt", "iris2.txt", "iris3.txt"),
      Preprocessing = Preprocessing[j],
      InformationCriterion = InformationCriterion[i],
      pdf = rep("normal", 4),
      K = K[[j]])

    ## Fill in Table 2.

    if (is.null(Table))
      Table <- REBMIX[[i, j]]$summary
    else
      Table <- merge(Table, REBMIX[[i, j]]$summary, all = TRUE, sort = FALSE)
  }
}


###################################################
### chunk number 13: rebmix-code
###################################################
#line 554 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Visualize Table 2.

Table


###################################################
### chunk number 14: iris-fig
###################################################
#line 647 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Visualize Figure 2.

plot(REBMIX[[2, 1]], nrow = 2, ncol = 3, npts = 1000)


###################################################
### chunk number 15: rebmix-code
###################################################
#line 659 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

##################
## Wine dataset ##
##################

data("wine")

## Split the wine dataset into three subsets for the three Cultivars
## and remove the Cultivar column from the datasets.

winecolnames <- !(colnames(wine) %in% "Cultivar")

wine1 <- wine[wine$Cultivar == 1, winecolnames]
wine2 <- wine[wine$Cultivar == 2, winecolnames]
wine3 <- wine[wine$Cultivar == 3, winecolnames]

wine <- wine[ , winecolnames]

## Write the datasets without the Cultivar information into the tab
## delimited ASCII files.

write.table(wine, file = "wine.txt", sep = "\t",
  eol = "\n", row.names = FALSE, col.names = FALSE)
write.table(wine1, file = "wine1.txt", sep = "\t",
  eol = "\n", row.names = FALSE, col.names = FALSE)
write.table(wine2, file = "wine2.txt", sep = "\t",
  eol = "\n", row.names = FALSE, col.names = FALSE)
write.table(wine3, file = "wine3.txt", sep = "\t",
  eol = "\n", row.names = FALSE, col.names = FALSE)

## Initialize REBMIX object.

REBMIX <- array(list(NULL), c(6, 3))

## Initialize Table 3.

Table <- NULL

## Estimate number of components, component weights and component parameters.

Preprocessing <- c("histogram", "Parzen window", "k-nearest neighbour")
InformationCriterion <- c("AIC", "AWE", "BIC", "CLC", "ICL", "ICL-BIC")
K <- list(6:27, 6:27, 3:14)

for (i in 1:6) {
  for (j in 1:3) {
    REBMIX[[i, j]] <- REBMIX(Dataset = c("wine.txt", "wine1.txt", "wine2.txt", "wine3.txt"),
      Preprocessing = Preprocessing[j],
      InformationCriterion = InformationCriterion[i],
      pdf = rep("normal", 13),
      K = K[[j]])

    ## Fill in Table 3.

    if (is.null(Table))
      Table <- REBMIX[[i, j]]$summary
    else
      Table <- merge(Table, REBMIX[[i, j]]$summary, all = TRUE, sort = FALSE)
  }
}

## Visualize Table 3.

Table


###################################################
### chunk number 16: wine-fig
###################################################
#line 727 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Visualize Figure 3.

plot(REBMIX[[6, 2]], nrow = 13, ncol = 6, npts = 1000, plot.cex = 0.3)


###################################################
### chunk number 17: rebmix-code
###################################################
#line 825 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

#######################
## Complex 1 dataset ##
#######################

## Generate the complex 1 dataset.

n <- c(998, 263, 1086, 487, 213, 1076, 232,
  784, 840, 461, 773, 24, 811, 1091, 861)

Theta <- rbind(pdf = "normal",
  theta1 = c(688.4, 265.1, 30.8, 934, 561.6, 854.9, 883.7,
  758.3, 189.3, 919.3, 98, 143, 202.5, 628, 977),
  theta2 = c(12.4, 14.6, 14.8, 8.4, 11.7, 9.2, 6.3, 10.2,
  9.5, 8.1, 14.7, 11.7, 7.4, 10.1, 14.6))

RNGMIX <- RNGMIX(Dataset = "complex1.txt",
  n = n,
  Theta = Theta)

## Estimate number of components, component weights and component parameters.

REBMIX <- REBMIX(Dataset = "complex1.txt",
  Preprocessing = "histogram",
  D = 0.0025,
  cmax = 30,
  InformationCriterion = "BIC",
  pdf = "normal",
  K = seq(14, 200, 4))

REBMIX$w[[1]]
REBMIX$Theta[[1]]
REBMIX$summary


###################################################
### chunk number 18: complex1-fig
###################################################
#line 862 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Visualize Figure 4.

plot(REBMIX, npts = 1000)


###################################################
### chunk number 19: rebmix-code
###################################################
#line 889 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

#########################
## Simulated 1 dataset ##
#########################

## Generate the simulated 1 dataset.

n <- c(75, 100, 125, 150, 175)

Theta <- rbind(rep("normal", 5),
  c(10, 8.5, 12, 13, 7),
  c(1, 1, 1, 2, 3),
  rep("normal", 5),
  c(12, 10.5, 14, 15, 9),
  c(1, 1, 1, 2, 3),
  rep("normal", 5),
  c(10, 8.5, 12, 7, 13),
  c(1, 1, 1, 2, 3),
  rep("normal", 5),
  c(12, 10.5, 14, 9, 15),
  c(1, 1, 1, 2, 3))

RNGMIX <- RNGMIX(Dataset = paste("Simulated1_", 1:100, ".txt", sep = ""),
  n = n,
  Theta = Theta)


###################################################
### chunk number 20: rebmix-code
###################################################
#line 917 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Estimate number of components, component weights and component parameters.

REBMIX <- REBMIX(paste("Simulated1_", 1:100, ".txt", sep = ""),
  Preprocessing = "histogram",
  InformationCriterion = "BIC",
  pdf = rep("normal", 4),
  K = seq(10, 28, 2))


###################################################
### chunk number 21: rebmix-code
###################################################
#line 928 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Visualize results.

c <- REBMIX$summary$c
IC <- REBMIX$summary$IC

summary(c)
summary(IC, digits = 5)


###################################################
### chunk number 22: simulated1-fig
###################################################
#line 940 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Probability of identifying 5 components.

P <- length(c[c == 5]) / length(c)
P

## Extract sample with the minimum BIC.

Min.IC <- min(IC)

summary <- REBMIX$summary[IC == Min.IC, ]

i <- as.numeric(rownames(summary))

## Visualize Figure 5.

plot(REBMIX, pos = i, nrow = 2, ncol = 3, npts = 1000)


###################################################
### chunk number 23: rebmix-code
###################################################
#line 962 "d:/Rcompile/CRANpkg/local/2.12/rebmix/inst/doc/rebmix.Rnw"

## Remove the created tab delimited ASCII files.

file.remove("galaxy.txt",
  "iris.txt", "iris1.txt", "iris2.txt", "iris3.txt",
  "wine.txt", "wine1.txt", "wine2.txt", "wine3.txt",
  "complex1.txt",
  paste("Simulated1_", 1:100, ".txt", sep = ""),
  "InpREBMIX.txt", "InpRNGMIX.txt",  
  "OutREBMIX_1.txt", "OutREBMIX_2.txt", "OutRNGMIX_1.txt")

rm(list = ls())


